<!--巡检计划-->
<template>
  <div class="tree-table-container">
    <div class="drag-box" ref="drag-box" v-if="componentName === 'table'">
      <div class="drag-left">
        <!--左侧div内容-->
        <div class="common-tree-container">
          <div class="common-tree-title">
            <i class="el-icon-menu" />巡检计划
          </div>
          <div class="common-tree-content">
            <el-tree highlight-current :data="planTreeList" default-expand-all :props="defaultProps"
              @node-click="handleNodeClick" />
          </div>
        </div>
      </div>
      <div class="drag-resize" title="收缩侧边栏">⋮</div>
      <div class="drag-mid">
        <!--右侧div内容-->
        <div class="common-table-container">
          <div class="bbsl-common-page">
            <div class="bbsl-table-search">
              <el-form v-model="queryParams" label-width="auto">
                <el-row :gutter="10">
                  <el-col :span="6">
                    <el-form-item label="巡查计划名称">
                      <el-input :clearable="true" placeholder="请输入巡查计划名称" v-model="queryParams['plan_Name_']" />
                    </el-form-item>
                  </el-col>
                  <el-col :span="6">
                    <el-form-item label="巡检类型">
                      <el-select placeholder="请选择巡检类型" v-model="queryParams['task_Type_']" clearable>
                        <el-option v-for="item in inspectionTypeOpt" :key="item.value" :label="item.name"
                          :value="item.value" />
                      </el-select>
                    </el-form-item>
                  </el-col>
                  <el-col :span="6">
                    <el-form-item label="任务时间" prop="startTime">
                      <el-date-picker clearable type="date" value-format="yyyy-MM-dd" style="width:100%"
                        placeholder="请选择巡查时间" v-model="queryParams['task_Date_']"></el-date-picker>
                    </el-form-item>
                  </el-col>
                  <el-col :span="4">
                    <el-button type="primary" icon="el-icon-search" @click="handleSearch">
                      搜索
                    </el-button>
                    <el-button icon="el-icon-refresh" @click="handleReset">
                      重置
                    </el-button>
                  </el-col>
                </el-row>
              </el-form>
            </div>
            <div class="bbsl-table-content" ref="contentPanel">
              <div class="bbsl-btn-content" ref="btnPanel">
              </div>
              <el-table border size="mini" v-loading="loading" ref="multipleSelection" :data="tableData"
                :style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
                :header-cell-style="{ 'text-align': 'center' }" @selection-change="handleSelectionChange"
                @sort-change="sortChange" row-key="id" @row-dblclick="row => openPage('isShowAddModify', row)">
                <!-- <el-table-column reserve-selection type="selection" width="55" align="center"></el-table-column> -->
                <el-table-column type="index" width="70" label="序号" align="center">
                </el-table-column>
                <el-table-column prop="planName" show-overflow-tooltip align="center" label="巡检计划名称" min-width="150" />
                <el-table-column prop="taskContent" show-overflow-tooltip align="center" label="巡检内容" min-width="150" />

                <el-table-column prop="taskType" show-overflow-tooltip align="center" label="巡检类型" min-width="100"
                  :formatter="({ taskType }) => dictionaryEscape(inspectionTypeOpt, taskType + '')" />
                <el-table-column prop="taskDate" show-overflow-tooltip min-width="100" align="center" label="任务时间" />
                <el-table-column show-overflow-tooltip min-width="100" align="center" label="任务状态">
                  <template v-slot="{ row }">
                    <template v-if="row.fillStatus < 2">
                      <el-tag v-if="row.taskStatus < 1" type="info">未开始</el-tag>
                      <el-tag v-else-if="row.taskStatus === 1">执行中</el-tag>
                    </template>
                    <el-tag v-else type="success">已完成</el-tag>
                  </template>
                </el-table-column>
                <el-table-column show-overflow-tooltip min-width="100" align="center" fixed="right" label="操作">
                  <template v-slot="{ row }">
                    <el-link type="primary" v-if="row.taskStatus === 1" :underline="false"
                      @click="openPage('isShowAddModify', row)">
                      录入
                    </el-link>
                    <el-link type="primary" v-if="row.taskStatus === 2" :underline="false"
                      @click="openPage('isShowAddModify', row)">
                      编辑
                    </el-link>
                    <!-- <el-link v-if="row.planStatus === 1" type="danger" :underline="false" style="margin-right: 15px;"
                      @click="handleRetract(row)">
                      撤回
                    </el-link>
                     -->
                  </template>
                </el-table-column>
              </el-table>
              <el-pagination align="right" background class="bbsl-pagination" ref="paginationPanel"
                @size-change="handleSizeChange" @current-change="handleCurrentChange" :current-page="queryParams.page"
                :page-sizes="[20, 30, 40, 50]" :page-size="queryParams.pageSize"
                layout="total, sizes, prev, pager, next, jumper" :total="queryParams.total"></el-pagination>
            </div>
          </div>
        </div>
      </div>
    </div>

    <!--  新增修改页面  -->
    <AddModifyPage v-if="componentName === 'isShowAddModify'" :inspectionTypeOpt="inspectionTypeOpt" :row-info="rowInfo"
      @closePage="closePage" />

    <DetailModifyPage v-if="componentName === 'isShowDetailModify'" :inspectionTypeOpt="inspectionTypeOpt"
      :row-info="rowInfo" @closePage="closePage" />
  </div>
</template>

<script>
import { TableMixin } from '@/mixins/tableMixin'
import { removePlanById, tableData, taskTableData, receivingTask } from '@/api/device/resourceInspection/resourceInspection'
import dictUtils from '@/components/dict/DictSelectUtils'
import { dictionaryEscape } from '@/utils/dictionary'
import AddModifyPage from './components/AddModifyPage/index.vue'
import DetailModifyPage from './components/DetailModifyPage/index.vue'

export default {
  name: 'DeviceInspectionResult',
  components: { AddModifyPage, DetailModifyPage },
  // 日常巡检
  mixins: [TableMixin],
  data() {
    return {
      planTreeList: [],
      isShowAddModify: false,
      isShowDetailModify: false,
      tableData: [],
      queryParams: {
        page: 1,
        pageSize: 20,
        total: 0,
        'plan_Name_': '', // 巡检计划名称
        'task_Date_': '',
        'task_Type_': '' // 巡检类型
      },
      sorter: [],
      inspectionTypeOpt: dictUtils.getDictItemsFromCache('xjlx') || [],
      rowInfo: {},
      componentName: 'table',
      defaultProps: {
        children: [],
        label: "planName"
      },
      planId: ''
    }
  },
  computed: {
    // 加工为后端需要的请求格式
    computedQuery() {
      const querys = [
        { operation: 'LIKE', property: 'plan_Name_' },
        { operation: 'EQUAL', property: 'task_Date_' },
        { operation: 'EQUAL', property: 'task_Type_' },
        { operation: 'EQUAL', property: 'plan_id_' },
      ]
      const { pageSize, page, ...item } = this.queryParams
      return {
        pageBean: { pageSize, page },
        querys: querys.flatMap(i => {
          /*
          * 取value值优先级：querys > queryParams
          * 方便后续有些参数默认值为一个固定的默认值，并且这个默认值不为空，也不会显示到页面上
          * */
          let value = i.value ?? item[i.property] ?? ''
          if (i.property === 'plan_id_') {
            value = this.planId
          }
          if (value === '') return []
          if (Array.isArray(value) && !value.length) return []
          return { group: 'main', relation: 'AND', ...i, value }
        }),
        sorter: this.sorter.filter(i => i.direction !== '')
      }
    }
  },
  created() {
    this.getPlanList()
  },
  methods: {
    dictionaryEscape,
    // 查询计划列表
    async getPlanList() {
      let data = {
        pageBean: { pageSize: -1, page: 1 },
        querys: [{
          group: "main",
          operation: "EQUAL",
          property: "plan_Status_",
          relation: "AND",
          value: "1"
        }]
      }
      const { rows } = await tableData(data)
      this.planTreeList = rows
    },
    // 根据计划查询任务
    handleNodeClick(data) {
      this.planId = data.id
      this.queryParams.page = 1
      this.loadData()
    },

    // 获取list
    async loadData() {
      this.loading = true
      const { rows, total } = await taskTableData(this.computedQuery)
      this.tableData = rows
      this.queryParams.total = total
      this.loading = false
    },

    // 顶部搜索
    handleSearch() {
      this.queryParams.page = 1
      this.loadData()
    },

    // 重置
    handleReset() {
      this.queryParams = this.$options.data().queryParams
      this.planId = ''
      this.loadData()
    },

    // 接收任务
    receivingTask(row) {
      this.$confirm(`确认接收任务？`, '提示', {
        confirmButtonText: '确认',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(_ => {
        this.loading = true
        receivingTask({ id: row.id, status: 1 }).then(res => {
          if (res.state) {
            this.$message.success('接收任务成功！')
            row.taskStatus = 1
          }
          this.loading = false
        })
      })

    },

    //分页页数
    handleCurrentChange(page) {
      this.queryParams.page = 1
      this.queryParams.page = page
      this.loadData()
    },

    //分页大小
    handleSizeChange(pageSize) {
      this.queryParams.page = 1
      this.queryParams.pageSize = pageSize
      this.loadData()
    },

    // 排序切换
    sortChange({ prop: property, order }) {
      let direction = ''
      switch (order) {
        case 'ascending':
          direction = 'ASC'
          break
        case 'descending':
          direction = 'DESC'
          break
      }
      this.sorter.forEach(i => {
        if (i.property !== property) return i.direction = ''
        i.direction = direction
      })
      this.loadData()
    },

    // 打开功能页面
    openPage(dialog, rowInfo = {}) {
      if (rowInfo.taskStatus === 0) {
        this.this.$confirm(`任务暂未接收，无法录入结果。`, '提示', {
          confirmButtonText: '确认',
          cancelButtonText: '取消',
          type: 'warning'
        }).then(_ => {

        })
      } else {
        this.componentName = dialog
        this.rowInfo = rowInfo
      }
    },

    // 关闭功能页面
    closePage(args) {
      switch (args) {
        case 'modify':
          this.queryParams.page = 1
          break
        case 'add':
          break
      }
      this.loadData()
      this.componentName = 'table'
      this.rowInfo = {}
    }
  }
}
</script>
<style lang="scss" scoped>
.common-tree-content {
  ::v-deep.el-tree-node__label {
    width: 220px;
    overflow: hidden;
    text-overflow: ellipsis;
  }
}

.type-tag {
  margin: 0 2px;
}

::v-deep .el-link {
  span {
    font-size: 14PX;
  }
}
</style>
